@@ -1,22 +1,22 @@
-// ************************************************************************* 
-// Copyright (c) 2014, SUSE LLC
-// 
+// *************************************************************************
+// Copyright (c) 2014-2017, SUSE LLC
+//
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
-// 
+//
 // 1. Redistributions of source code must retain the above copyright notice,
 // this list of conditions and the following disclaimer.
-// 
+//
 // 2. Redistributions in binary form must reproduce the above copyright
 // notice, this list of conditions and the following disclaimer in the
 // documentation and/or other materials provided with the distribution.
-// 
+//
 // 3. Neither the name of SUSE LLC nor the names of its contributors may be
 // used to endorse or promote products derived from this software without
 // specific prior written permission.
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 // AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 // IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -28,7 +28,7 @@
 // CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
-// ************************************************************************* 
+// *************************************************************************
 //
 // lib.js
 //
@@ -45,6 +45,7 @@ define ([
 ) {
 
     var heldObject = null,
+        dbrowserStateOverride = false,
         dbrowserState = {
             "obj": null,  // the dbrowser object itself
             "set": null,  // the dataset (array) we are browsing
@@ -83,6 +84,11 @@ define ([
             $('#result').html('&nbsp;');
         },
 
+        ajaxMessage: function () {
+            $('#result').css('text-align', 'center');
+            $('#result').html('* * * AJAX call * * *');
+        },
+
         // given an object, hold (store) it
         // if called without argument, just return whatever object we are holding
         holdObject: function (obj) {
@@ -270,6 +276,11 @@ define ([
                 return true;
             }
             return false;
+        },
+
+        isObjEmpty: function (obj) {
+            if (Object.getOwnPropertyNames(obj).length > 0) return false;
+            return true;
         }
     };
 });
