@@ -1,22 +1,22 @@
-// ************************************************************************* 
-// Copyright (c) 2014, SUSE LLC
-// 
+// *************************************************************************
+// Copyright (c) 2014-2017, SUSE LLC
+//
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
-// 
+//
 // 1. Redistributions of source code must retain the above copyright notice,
 // this list of conditions and the following disclaimer.
-// 
+//
 // 2. Redistributions in binary form must reproduce the above copyright
 // notice, this list of conditions and the following disclaimer in the
 // documentation and/or other materials provided with the distribution.
-// 
+//
 // 3. Neither the name of SUSE LLC nor the names of its contributors may be
 // used to endorse or promote products derived from this software without
 // specific prior written permission.
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 // AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 // IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -44,14 +44,14 @@ define ([
     currentUser
 ) {
 
+    var prefix = "core: ";
+
     return function () {
-        test('currentUser object', function () {
+        test(prefix + 'currentUser object', function (assert) {
 
             ok(currentUser().hasOwnProperty('obj'), "currentUser.obj OK");
             ok(currentUser().hasOwnProperty('priv'), "currentUser.priv OK");
             ok(currentUser().obj.hasOwnProperty('nick'), "currentUser.obj.nick OK");
-            ok(currentUser().obj.hasOwnProperty('passhash'), "currentUser.obj.passhash OK");
-            ok(currentUser().obj.hasOwnProperty('salt'), "currentUser.obj.salt OK");
 
         });
     };
